==> zio-aws-route53_2.13-7.28.29.7-sources.jar: zio/aws/route53/model/GetGeoLocationRequest.scala <==
package zio.aws.route53.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.route53.model.primitives.{
  GeoLocationSubdivisionCode,
  GeoLocationCountryCode,
  GeoLocationContinentCode
}
import scala.jdk.CollectionConverters._
final case class GetGeoLocationRequest(
    continentCode: Optional[GeoLocationContinentCode] = Optional.Absent,
    countryCode: Optional[GeoLocationCountryCode] = Optional.Absent,
    subdivisionCode: Optional[GeoLocationSubdivisionCode] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53.model.GetGeoLocationRequest = {
    import GetGeoLocationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53.model.GetGeoLocationRequest
      .builder()
      .optionallyWith(
        continentCode.map(value =>
          GeoLocationContinentCode.unwrap(value): java.lang.String
        )
      )(_.continentCode)
      .optionallyWith(
        countryCode.map(value =>
          GeoLocationCountryCode.unwrap(value): java.lang.String
        )
      )(_.countryCode)
      .optionallyWith(
        subdivisionCode.map(value =>
          GeoLocationSubdivisionCode.unwrap(value): java.lang.String
        )
      )(_.subdivisionCode)
      .build()
  }
  def asReadOnly: zio.aws.route53.model.GetGeoLocationRequest.ReadOnly =
    zio.aws.route53.model.GetGeoLocationRequest.wrap(buildAwsValue())
}
object GetGeoLocationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53.model.GetGeoLocationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53.model.GetGeoLocationRequest =
      zio.aws.route53.model.GetGeoLocationRequest(
        continentCode.map(value => value),
        countryCode.map(value => value),
        subdivisionCode.map(value => value)
      )
    def continentCode: Optional[GeoLocationContinentCode]
    def countryCode: Optional[GeoLocationCountryCode]
    def subdivisionCode: Optional[GeoLocationSubdivisionCode]
    def getContinentCode: ZIO[Any, AwsError, GeoLocationContinentCode] =
      AwsError.unwrapOptionField("continentCode", continentCode)
    def getCountryCode: ZIO[Any, AwsError, GeoLocationCountryCode] =
      AwsError.unwrapOptionField("countryCode", countryCode)
    def getSubdivisionCode: ZIO[Any, AwsError, GeoLocationSubdivisionCode] =
      AwsError.unwrapOptionField("subdivisionCode", subdivisionCode)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53.model.GetGeoLocationRequest
  ) extends zio.aws.route53.model.GetGeoLocationRequest.ReadOnly {
    override val continentCode: Optional[GeoLocationContinentCode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.continentCode())
        .map(value =>
          zio.aws.route53.model.primitives.GeoLocationContinentCode(value)
        )
    override val countryCode: Optional[GeoLocationCountryCode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.countryCode())
        .map(value =>
          zio.aws.route53.model.primitives.GeoLocationCountryCode(value)
        )
    override val subdivisionCode: Optional[GeoLocationSubdivisionCode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.subdivisionCode())
        .map(value =>
          zio.aws.route53.model.primitives.GeoLocationSubdivisionCode(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53.model.GetGeoLocationRequest
  ): zio.aws.route53.model.GetGeoLocationRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-route53_3-5.17.116.1-sources.jar: zio/aws/route53/model/GetGeoLocationRequest.scala <==
package zio.aws.route53.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.route53.model.primitives.{
  GeoLocationSubdivisionCode,
  GeoLocationCountryCode,
  GeoLocationContinentCode
}
import scala.jdk.CollectionConverters.*
final case class GetGeoLocationRequest(
    continentCode: Option[GeoLocationContinentCode] = None,
    countryCode: Option[GeoLocationCountryCode] = None,
    subdivisionCode: Option[GeoLocationSubdivisionCode] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53.model.GetGeoLocationRequest = {
    import GetGeoLocationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53.model.GetGeoLocationRequest
      .builder()
      .optionallyWith(
        continentCode.map(value =>
          GeoLocationContinentCode.unwrap(value): java.lang.String
        )
      )(_.continentCode)
      .optionallyWith(
        countryCode.map(value =>
          GeoLocationCountryCode.unwrap(value): java.lang.String
        )
      )(_.countryCode)
      .optionallyWith(
        subdivisionCode.map(value =>
          GeoLocationSubdivisionCode.unwrap(value): java.lang.String
        )
      )(_.subdivisionCode)
      .build()
  }
  def asReadOnly: zio.aws.route53.model.GetGeoLocationRequest.ReadOnly =
    zio.aws.route53.model.GetGeoLocationRequest.wrap(buildAwsValue())
}
object GetGeoLocationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53.model.GetGeoLocationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53.model.GetGeoLocationRequest =
      zio.aws.route53.model.GetGeoLocationRequest(
        continentCode.map(value => value),
        countryCode.map(value => value),
        subdivisionCode.map(value => value)
      )
    def continentCode: Option[GeoLocationContinentCode]
    def countryCode: Option[GeoLocationCountryCode]
    def subdivisionCode: Option[GeoLocationSubdivisionCode]
    def getContinentCode: ZIO[Any, AwsError, GeoLocationContinentCode] =
      AwsError.unwrapOptionField("continentCode", continentCode)
    def getCountryCode: ZIO[Any, AwsError, GeoLocationCountryCode] =
      AwsError.unwrapOptionField("countryCode", countryCode)
    def getSubdivisionCode: ZIO[Any, AwsError, GeoLocationSubdivisionCode] =
      AwsError.unwrapOptionField("subdivisionCode", subdivisionCode)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53.model.GetGeoLocationRequest
  ) extends zio.aws.route53.model.GetGeoLocationRequest.ReadOnly {
    override val continentCode: Option[GeoLocationContinentCode] = scala
      .Option(impl.continentCode())
      .map(value =>
        zio.aws.route53.model.primitives.GeoLocationContinentCode(value)
      )
    override val countryCode: Option[GeoLocationCountryCode] = scala
      .Option(impl.countryCode())
      .map(value =>
        zio.aws.route53.model.primitives.GeoLocationCountryCode(value)
      )
    override val subdivisionCode: Option[GeoLocationSubdivisionCode] = scala
      .Option(impl.subdivisionCode())
      .map(value =>
        zio.aws.route53.model.primitives.GeoLocationSubdivisionCode(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53.model.GetGeoLocationRequest
  ): zio.aws.route53.model.GetGeoLocationRequest.ReadOnly = new Wrapper(impl)
}
